@@ -9,10 +9,10 @@ def print_info() -> None:
     Print package info to stdout.
     """
     print(
-        "Type annotations for boto3.RedshiftServerless 1.24.11\nVersion:         1.24.11\nBuilder"
-        " version: 7.11.4\nDocs:           "
+        "Type annotations for boto3.RedshiftServerless 1.24.20\nVersion:         1.24.20\nBuilder"
+        " version: 7.7.2\nDocs:           "
         " https://youtype.github.io/boto3_stubs_docs/mypy_boto3_redshift_serverless//\nBoto3 docs: "
-        "     https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/redshiftserverless.html#RedshiftServerless\nOther"
+        "     https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/redshift-serverless.html#RedshiftServerless\nOther"
         " services:  https://pypi.org/project/boto3-stubs/\nChangelog:      "
         " https://github.com/youtype/mypy_boto3_builder/releases"
     )
@@ -22,7 +22,7 @@ def print_version() -> None:
     """
     Print package version to stdout.
     """
-    print("1.24.11")
+    print("1.24.20")
 
 
 def main() -> None:
